pub struct FrameData {
pub info: IntegrationInfo,
pub output: AppOutput,
pub repaint_signal: Arc<dyn RepaintSignal>,
}Expand description
The data required by Frame each frame.
Fields
info: IntegrationInfoInformation about the integration.
output: AppOutputWhere the app can issue commands back to the integration.
repaint_signal: Arc<dyn RepaintSignal>If you need to request a repaint from another thread, clone this and send it to that other thread.